@@ -22,7 +22,6 @@ use std::{
 	borrow::Borrow,
 	cmp::Ordering,
 	collections::HashSet,
-	convert::TryFrom,
 	fmt,
 	hash::{
 		Hash,
@@ -387,7 +386,7 @@ impl ProglessInner {
 	/// Return the last-recorded elapsed time in seconds. Realtime elapsed
 	/// values are pulled from the field directly.
 	fn elapsed(&self) -> u32 {
-		num_integer::div_floor(self.elapsed.load(SeqCst), 1000)
+		dactyl::div_u32(self.elapsed.load(SeqCst), 1000)
 	}
 
 	#[inline]
@@ -691,7 +690,7 @@ impl ProglessInner {
 		if done == total { (space, 0) }
 		// Working on it!
 		else {
-			let o_done: u8 = u8::saturating_from(num_integer::div_floor(done * u32::from(space), total));
+			let o_done: u8 = u8::saturating_from(dactyl::div_u32(done * u32::from(space), total));
 			(o_done, space.saturating_sub(o_done))
 		}
 	}
@@ -788,11 +787,11 @@ impl ProglessInner {
 		// Throttle back-to-back ticks.
 		if now.saturating_sub(before) < 60 { return None; }
 
-		let secs: u32 = num_integer::div_floor(now, 1000);
+		let secs: u32 = dactyl::div_u32(now, 1000);
 		self.elapsed.store(now, SeqCst);
 
 		// No change to the seconds bit.
-		if secs == num_integer::div_floor(before, 1000) { Some(false) }
+		if secs == dactyl::div_u32(before, 1000) { Some(false) }
 		else {
 			let [h, m, s] = NiceElapsed::hms(secs);
 			unsafe {
@@ -925,7 +924,6 @@ impl Drop for ProglessSteady {
 ///
 /// ```no_run
 /// use fyi_msg::Progless;
-/// use std::convert::TryFrom;
 ///
 /// // You can use [`Progless::try_from`] for any unsigned integer type, or the
 /// // infallible [`Progless::from`] on an [`std::num::NonZeroU32`].
@@ -959,7 +957,6 @@ impl Drop for ProglessSteady {
 /// ```ignore
 /// # use fyi_msg::Progless;
 /// # use rayon::prelude::*;
-/// # use std::convert::TryFrom;
 ///
 /// # let pbar = Progless::try_from(1001_u32).unwrap();
 ///
@@ -1002,9 +999,9 @@ impl TryFrom<u32> for Progless {
 	}
 }
 
-/// # Helper: TryFrom
+/// # Helper: `TryFrom`
 ///
-/// This will generate TryFrom implementations for various integer types, both
+/// This will generate `TryFrom` implementations for various integer types, both
 /// bigger and smaller than the target `u32`.
 macro_rules! impl_tryfrom {
 	// These types fit into u32.
@@ -1076,7 +1073,6 @@ impl Progless {
 	///
 	/// ```no_run
 	/// use fyi_msg::{Msg, Progless};
-	/// use std::convert::TryFrom;
 	///
 	/// // Initialize with a `u32` total.
 	/// let pbar = Progless::try_from(1001_u32).unwrap()
@@ -1111,7 +1107,6 @@ impl Progless {
 	///
 	/// ```no_run
 	/// use fyi_msg::Progless;
-	/// use std::convert::TryFrom;
 	///
 	/// // Initialize with a `u32` total.
 	/// let pbar = Progless::try_from(1001_u32).unwrap();
@@ -1146,7 +1141,6 @@ impl Progless {
 	///
 	/// ```no_run
 	/// use fyi_msg::{MsgKind, Progless};
-	/// use std::convert::TryFrom;
 	///
 	/// // Initialize with a `u32` total.
 	/// let pbar = Progless::try_from(1001_u32).unwrap();
@@ -1198,7 +1192,6 @@ impl Progless {
 	///
 	/// ```no_run
 	/// use fyi_msg::Progless;
-	/// use std::convert::TryFrom;
 	///
 	/// // Initialize with a `u32` total.
 	/// let pbar = Progless::try_from(1001_u32).unwrap();
